package com.ruoyi.system.service.project;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.project.BmConstructionPayInfo;

import java.util.List;

/**
 * 项目入统Service接口
 * 
 * @author ruoyi
 * @date 2021-03-08
 */
public interface IBmConstructionPayInfoService 
{
    /**
     * 查询项目入统
     * 
     * @param id 项目入统ID
     * @return 项目入统
     */
    public BmConstructionPayInfo selectBmConstructionPayInfoById(Long id);

    /**
     * 查询项目入统列表
     * 
     * @param bmConstructionPayInfo 项目入统
     * @return 项目入统集合
     */
    public List<BmConstructionPayInfo> selectBmConstructionPayInfoList(BmConstructionPayInfo bmConstructionPayInfo);

    /**
     * 新增项目入统
     * 
     * @param bmConstructionPayInfo 项目入统
     * @return 结果
     */
    public AjaxResult insertBmConstructionPayInfo(BmConstructionPayInfo bmConstructionPayInfo);

    /**
     * 修改项目入统
     * 
     * @param bmConstructionPayInfo 项目入统
     * @return 结果
     */
    public AjaxResult updateBmConstructionPayInfo(BmConstructionPayInfo bmConstructionPayInfo);

    /**
     * 批量删除项目入统
     * 
     * @param ids 需要删除的项目入统ID
     * @return 结果
     */
    public int deleteBmConstructionPayInfoByIds(Long[] ids);

    /**
     * 删除项目入统信息
     * 
     * @param id 项目入统ID
     * @return 结果
     */
    public int deleteBmConstructionPayInfoById(Long id);
}
